@@ -2,15 +2,19 @@ import os
 
 from peewee import (BooleanField, CharField, DateField, ForeignKeyField,
                     IntegerField, Model, SqliteDatabase, DoesNotExist)
+
 from tmc.errors import NoCourseSelected, NoExerciseSelected
 
-# SqliteDatabase will fail if there is no ~/.config
-if not os.path.isdir(os.path.join(os.path.expanduser("~"), ".config")):
-    os.mkdir(os.path.join(os.path.expanduser("~"), ".config"), 0o700)
+target_file = os.environ.get("TMC_DATABASEFILE",
+                             os.path.join(os.path.expanduser("~"),
+                                          ".config",
+                                          "tmc.db"))
 
-sqlite = SqliteDatabase(
-    os.path.join(os.path.expanduser("~"), ".config", "tmc.db")
-)
+# SqliteDatabase will fail if the parent directory isn't there.
+if not os.path.isdir(os.path.dirname(target_file)):
+    os.mkdir(os.path.dirname(target_file), 0o700)
+
+sqlite = SqliteDatabase(target_file)
 sqlite.connect()
 
 
@@ -151,6 +155,14 @@ class Config(BaseModel):
     def get_value(name):
         return Config.get(Config.name == name).value
 
+    @staticmethod
+    def has_name(name):
+        try:
+            Config.get(Config.name == name)
+            return True
+        except DoesNotExist:
+            return False
+
     @staticmethod
     def has():
         try:
